package com.logicbig.example;

import org.springframework.beans.BeanWrapperImpl;
import java.beans.PropertyEditorSupport;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

public class LocalDateEditorExample {

    public static void main(String[] args) {
        Person person = new Person();
        BeanWrapperImpl bw = new BeanWrapperImpl(person);
        bw.registerCustomEditor(LocalDate.class,
                new LocalDateEditor(DateTimeFormatter.ofPattern("yyyy/MM/dd")));
        bw.setPropertyValue("name", "Tim");
        bw.setPropertyValue("dateOfBirth", "1984/07/06");
        System.out.println(person);
    }

    private static class Person{
        private String name;
        private LocalDate dateOfBirth;

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public LocalDate getDateOfBirth() {
            return dateOfBirth;
        }

        public void setDateOfBirth(LocalDate dateOfBirth) {
            this.dateOfBirth = dateOfBirth;
        }

        @Override
        public String toString() {
            return "Person{" +
                    "name='" + name + '\'' +
                    ", dateOfBirth=" + dateOfBirth +
                    '}';
        }
    }

    public static class LocalDateEditor extends PropertyEditorSupport {
        private final DateTimeFormatter formatter;

        public LocalDateEditor(DateTimeFormatter formatter) {
            this.formatter = formatter;
        }

        @Override
        public void setAsText(String text) throws IllegalArgumentException {
            setValue(LocalDate.parse(text,  formatter));
        }

        @Override
        public String getAsText() {
            return getValue().toString();
        }
    }
}